import { BasicColumn } from '/@/components/Table';
import { FormSchema } from '/@/components/Table';
import { rules } from '/@/utils/helper/validator';
import { render } from '/@/utils/common/renderUtils';
//列表数据
export const columns: BasicColumn[] = [
  {
    title: '宿舍信息',
    align: 'center',
    dataIndex: 'dormitory',
  },
  {
    title: '宿舍类型（男/女）',
    align: 'center',
    dataIndex: 'dormitoryType',
  },
  {
    title: '宿舍人数',
    align: 'center',
    dataIndex: 'dormitoryNum',
  },
  {
    title: '状态',
    align: 'center',
    dataIndex: 'dormitoryStatus',
  },
];
//查询数据
export const searchFormSchema: FormSchema[] = [];
//表单数据
export const formSchema: FormSchema[] = [
  {
    label: '宿舍信息',
    field: 'dormitory',
    component: 'Input',
    dynamicRules: ({ model, schema }) => {
      return [{ required: true, message: '请输入宿舍信息!' }];
    },
  },
  {
    label: '男/女',
    field: 'dormitoryType',
    component: 'RadioGroup',
    componentProps: {
      options: [
        { label: '男', value: 0 },
        { label: '女', value: 1 },
      ],
    },
    dynamicRules: ({ model, schema }) => {
      return [{ required: true, message: '请选择男/女!' }];
    },
  },
  {
    label: '宿舍人数',
    field: 'dormitoryNum',
    component: 'InputNumber',
    dynamicRules: ({ model, schema }) => {
      return [{ required: true, message: '请输入宿舍人数!' }];
    },
  },
  {
    label: '宿舍状态',
    //0没满，1已满
    field: 'dormitoryStatus',
    component: 'RadioGroup',
    componentProps: {
      options: [
        { label: '未满', value: 0 },
        { label: '已满', value: 1 },
      ],
    },
    dynamicRules: ({ model, schema }) => {
      return [{ required: true, message: '请选择宿舍状态' }];
    },
  },
  // TODO 主键隐藏字段，目前写死为ID
  {
    label: '',
    field: 'id',
    component: 'Input',
    show: false,
  },
];

// 高级查询数据
export const superQuerySchema = {
  dormitory: { title: '宿舍信息', order: 0, view: 'text', type: 'string' },
  dormitoryType: { title: '男/女', order: 1, view: 'text', type: 'string' },
  dormitoryNum: { title: '宿舍人数', order: 2, view: 'number', type: 'number' },
  dormitoryStatus: { title: '宿舍状态0没满，1已满', order: 3, view: 'text', type: 'string' },
};

/**
 * 流程表单调用这个方法获取formSchema
 * @param param
 */
export function getBpmFormSchema(_formData): FormSchema[] {
  // 默认和原始表单保持一致 如果流程中配置了权限数据，这里需要单独处理formSchema
  return formSchema;
}
