import {defHttp} from '/@/utils/http/axios';
import { useMessage } from "/@/hooks/web/useMessage";

const { createConfirm } = useMessage();

enum Api {
  list = '/cees/ceesGroup/list',
  save='/cees/ceesGroup/add',
  edit='/cees/ceesGroup/edit',
  deleteOne = '/cees/ceesGroup/delete',
  deleteBatch = '/cees/ceesGroup/deleteBatch',
  importExcel = '/cees/ceesGroup/importExcel',
  exportXls = '/cees/ceesGroup/exportXls',
  getRowUser = '/cees/ceesGroup/getRowUser',
}
/**
 * 导出api
 * @param params
 */
export const getExportUrl = Api.exportXls;
/**
 * 导入api
 */
export const getImportUrl = Api.importExcel;
/**
 * 列表接口
 * @param params
 */
export const list = (params) =>
  defHttp.get({url: Api.list, params}).then((res) => {
    //添加组员信息
    res.records.map((item) => {
      getRowUser({groupId: item.id}).then((data) => {
        item.rowUser = data.map((item2) => item2.userName).join(',');
      }).catch((error) => {
        item.rowUser = '加载失败';
      });
  });
  console.log(res.records);
  return res.records;
});

//查询组员
export const getRowUser = (params) =>
  defHttp.get({url: Api.getRowUser, params});

/**
 * 删除单个
 */
export const deleteOne = (params,handleSuccess) => {
  return defHttp.delete({url: Api.deleteOne, params}, {joinParamsToUrl: true}).then(() => {
    handleSuccess();
  });
}
/**
 * 批量删除
 * @param params
 */
export const batchDelete = (params, handleSuccess) => {
  createConfirm({
    iconType: 'warning',
    title: '确认删除',
    content: '是否删除选中数据',
    okText: '确认',
    cancelText: '取消',
    onOk: () => {
      return defHttp.delete({url: Api.deleteBatch, data: params}, {joinParamsToUrl: true}).then(() => {
        handleSuccess();
      });
    }
  });
}
/**
 * 保存或者更新
 * @param params
 */
export const saveOrUpdate = (params, isUpdate) => {
  let url = isUpdate ? Api.edit : Api.save;
  return defHttp.post({url: url, params});
}
