import { defHttp } from '/@/utils/http/axios';
import { useMessage } from '/@/hooks/web/useMessage';

const { createConfirm } = useMessage();

enum Api {
  list = '/CEES/ceesLocalTeacher/list',
  save = '/CEES/ceesLocalTeacher/add',
  edit = '/CEES/ceesLocalTeacher/edit',
  deleteOne = '/CEES/ceesLocalTeacher/delete',
  deleteBatch = '/CEES/ceesLocalTeacher/deleteBatch',
  importExcel = '/CEES/ceesLocalTeacher/importExcel',
  exportXls = '/CEES/ceesLocalTeacher/exportXls',
  updateGroupUser = '/cees/ceesGroup/updateGroupUser',
  batchGroup = '/CEES/ceesLocalTeacher/batchGroup',
}

//获取分组
export const getGroup = () =>
  defHttp.get({ url: '/cees/ceesGroup/list' }).then((res) => {
    return res.records;
  });
/**
 * 导出api
 * @param params
 */
export const getExportUrl = Api.exportXls;
/**
 * 导入api
 */
export const getImportUrl = Api.importExcel;
/**
 * 列表接口
 * @param params
 */
export const list = (params) => defHttp.get({ url: Api.list, params });

/**
 * 删除单个
 */
export const deleteOne = (params, handleSuccess) => {
  return defHttp.delete({ url: Api.deleteOne, params }, { joinParamsToUrl: true }).then(() => {
    handleSuccess();
  });
};
/**
 * 批量删除
 * @param params
 */
export const batchDelete = (params, handleSuccess) => {
  createConfirm({
    iconType: 'warning',
    title: '确认删除',
    content: '是否删除选中数据',
    okText: '确认',
    cancelText: '取消',
    onOk: () => {
      return defHttp.delete({ url: Api.deleteBatch, data: params }, { joinParamsToUrl: true }).then(() => {
        handleSuccess();
      });
    },
  });
};
/**
 * 批量分组
 * @param params
 */
export const batchGroup = (params, handleSuccess) => {
  console.log('params', params);
  createConfirm({
    iconType: 'warning',
    title: '确认分组',
    content: '是否分组选中数据',
    okText: '确认',
    cancelText: '取消',
    onOk: () => {
      return defHttp.post({ url: Api.batchGroup, data: params }, { joinParamsToUrl: true }).then(() => {
        handleSuccess();
      });
    },
  });
};

//更新分组中间表
export const updateGroupUser = (params) => {
  return defHttp.post({ url: Api.updateGroupUser, params });
};

/**
 * 保存或者更新
 * @param params
 */
export const saveOrUpdate = (params, isUpdate) => {
  const url = isUpdate ? Api.edit : Api.save;
  // 更新分组中间表
  const groupUserParams = {
    userId: params.userId,
    groupId: params.groupId,
  };
  updateGroupUser(groupUserParams);
  return defHttp.post({ url: url, params });
};
